# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V11::Enums::AssetSetTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                => "UNSPECIFIED",
  UNKNOWN                    => "UNKNOWN",
  PAGE_FEED                  => "PAGE_FEED",
  DYNAMIC_EDUCATION          => "DYNAMIC_EDUCATION",
  MERCHANT_CENTER_FEED       => "MERCHANT_CENTER_FEED",
  DYNAMIC_REAL_ESTATE        => "DYNAMIC_REAL_ESTATE",
  DYNAMIC_CUSTOM             => "DYNAMIC_CUSTOM",
  DYNAMIC_HOTELS_AND_RENTALS => "DYNAMIC_HOTELS_AND_RENTALS",
  DYNAMIC_FLIGHTS            => "DYNAMIC_FLIGHTS",
  DYNAMIC_TRAVEL             => "DYNAMIC_TRAVEL",
  DYNAMIC_LOCAL              => "DYNAMIC_LOCAL",
  DYNAMIC_JOBS               => "DYNAMIC_JOBS"
];

1;
