# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V12::Enums::IncomeRangeTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED               => "UNSPECIFIED",
  UNKNOWN                   => "UNKNOWN",
  INCOME_RANGE_0_50         => "INCOME_RANGE_0_50",
  INCOME_RANGE_50_60        => "INCOME_RANGE_50_60",
  INCOME_RANGE_60_70        => "INCOME_RANGE_60_70",
  INCOME_RANGE_70_80        => "INCOME_RANGE_70_80",
  INCOME_RANGE_80_90        => "INCOME_RANGE_80_90",
  INCOME_RANGE_90_UP        => "INCOME_RANGE_90_UP",
  INCOME_RANGE_UNDETERMINED => "INCOME_RANGE_UNDETERMINED"
];

1;
